@@ -107,7 +107,8 @@ bool QClipAnimatorPrivate::canPlay() const
     The properties for controlling the animator are provided by the QAbstractClipAnimator base
     class.
 
-    \sa QAbstractClipAnimator, QAbstractAnimationClip, QChannelMapper, QBlendedClipAnimator
+    \sa Qt3DAnimation::QAbstractClipAnimator, Qt3DAnimation::QAbstractAnimationClip,
+        Qt3DAnimation::QChannelMapper, Qt3DAnimation::QBlendedClipAnimator
 */
 
 QClipAnimator::QClipAnimator(Qt3DCore::QNode *parent)
@@ -162,21 +163,6 @@ void QClipAnimator::setClip(QAbstractAnimationClip *clip)
     emit clipChanged(clip);
 }
 
-/*! \internal */
-Qt3DCore::QNodeCreatedChangeBasePtr QClipAnimator::createNodeCreationChange() const
-{
-    auto creationChange = Qt3DCore::QNodeCreatedChangePtr<QClipAnimatorData>::create(this);
-    auto &data = creationChange->data;
-    Q_D(const QClipAnimator);
-    data.clipId = Qt3DCore::qIdForNode(d->m_clip);
-    data.mapperId = Qt3DCore::qIdForNode(d->m_mapper);
-    data.clockId = Qt3DCore::qIdForNode(d->m_clock);
-    data.running = d->m_running;
-    data.loops = d->m_loops;
-    data.normalizedTime = d->m_normalizedTime;
-    return creationChange;
-}
-
 } // namespace Qt3DAnimation
 
 QT_END_NAMESPACE
